﻿//-----------------------------------------------------------------------
// <copyright file="Constants.cs" company="BME MIT" />
//-----------------------------------------------------------------------
/*
 * Name:    LogCategories, LogEventIds
 * Author:  Zoltan Micskei, BME MIT
 * Date:    2011.04.17.
 * Desc:    ConsoleGuessGame sample application for demonstrating manageable applications 
 *          see: http://www.inf.mit.bme.hu/edu/bsc/irf
 *          
 *          Structs and enums containing constants for logging and performance counter
 */

namespace IRF.ConsoleGuessGame
{
    /// <summary>
    /// Stores category strings defined in the Logging application blocks
    /// </summary>
    internal struct LogCategories
    {
        /// <summary>
        /// Log category string representing the business part of the application
        /// </summary>
        internal const string Program = "ConsoleGuessGame";

        /// <summary>
        /// Log category string representing the provider part of the application
        /// </summary>
        internal const string Provider = "GuessGameProvider";

        /// <summary>
        /// Log category representing Activity Tracing entries
        /// </summary>
        internal const string Tracing = "Tracing";
    }

    /// <summary>
    /// Stores all the log event Ids used in the program in a typed way
    /// </summary>
    internal struct LogEventIds
    {
        #region Success events
        /// <summary>
        /// Id for the successful program initialization event
        /// </summary>
        internal const int SuccessfullInitialization = 101;

        /// <summary>
        /// Id for new guess received event
        /// </summary>
        internal const int NewGuessReceived = 102;

        /// <summary>
        /// Id for the provider successfully created event
        /// </summary>
        internal const int ProviderCreated = 103;

        /// <summary>
        /// Id for the provider's constructor called event
        /// </summary>
        internal const int ProviderConstructorCalled = 104;
        #endregion

        #region Failure events
        /// <summary>
        /// Id for the invalid startup parameters event
        /// </summary>
        internal const int InvalidStartupParams = 201;

        /// <summary>
        /// Id for the provider creation failure event
        /// </summary>
        internal const int ProviderNotCreated = 202;

        /// <summary>
        /// Id for the invalid guess received event
        /// </summary>
        internal const int InvalidGuess = 203;

        /// <summary>
        /// Id for the provider could not access the game object event
        /// </summary>
        internal const int ProviderCouldNotAccessGame = 204;

        /// <summary>
        /// Id for the game creation failure event
        /// </summary>
        internal const int GameNotCreated = 205;
        #endregion
    }

    /// <summary>
    /// Constants for the performance counters of the application
    /// </summary>
    internal struct Counters
    {
        /// <summary>
        /// Name of the performance counter category belonging to the application
        /// </summary>
        internal const string CategoryName = "ConsoleGuessGame";
    }
}
